Atlas Interpolation
===================
The Allen Brain Institute hosts a rich database of mouse brain imagery. It
contains a large number of gene expression datasets obtained
through the in situ hybridization (ISH) staining. While for a given gene
a number of datasets corresponding to different specimen can be found, each of
these datasets only contains sparse section images that do not form a
continuous volume. This package explores techniques that allow to interpolate
the missing slices and thus reconstruct whole gene expression volumes.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   installation
   data
   examples
   vendors

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   api/atlinter
